Function amazon_sp_product_fees::apis::fees_api::get_my_fees_estimates
source · [−]pub async fn get_my_fees_estimates(
configuration: &Configuration,
body: Vec<FeesEstimateByIdRequest>
) -> Result<Vec<FeesEstimateResult>, Error>Expand description
Returns the estimated fees for a list of products. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.5 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.